pub fn list_projects() -> Vec<ProjectEntry>Expand description
List all registered projects that still have a .wipe board, annotating each
with its current board name.
pub fn list_projects() -> Vec<ProjectEntry>List all registered projects that still have a .wipe board, annotating each
with its current board name.