pub async fn serve(cfg: ServeConfig) -> Result<()>Expand description
Start the daemon and serve until the process is stopped (Ctrl-C).
pub async fn serve(cfg: ServeConfig) -> Result<()>Start the daemon and serve until the process is stopped (Ctrl-C).